Collection of methods, utilities and data sets for the support of spatial ecology analyses with a focus on pre-, core and post- modelling analyses of species distribution, niche quantification and community assembly.Specifically,
-Pre-modelling:
Spatial autocorrelation --> ecospat.mantel.correlogram;
Variable selection --> ecospat.npred;
Extrapolation Detection --> ecospat.exdet, ecospat.mess and ecospat.plot.mess;
Phylogenetic diversity measures --> ecospat.calculate.pd;
Biotic Interactions --> ecospat.co-occurrences and ecospat.Cscore;
Niche Quantification --> ecospat.grid.clim.dyn, ecospat.niche.equivalency.test, ecospat.niche.similarity.test, ecospat.plot.niche, ecospat.plot.niche.dyn, ecospat.plot.contrib, ecospat.niche.overlap, ecospat.plot.overlap.test, ecospat.niche.dyn.index and ecospat.shift.centroids;
Data Preparation --> ecospat.caleval, ecospat.cor.plot, ecospat.makeDataFrame, ecospat.occ.desaggregation, ecospat.rand.pseudoabsences, ecospat.rcls.grd, ecospat.recstrat_prop, ecospat.recstrat_regl and ecospat.sample.envar;
-Core Niche Modelling:
Model evaluation --> ecospat.cv.glm, ecospat.permut.glm, ecospat.cv.gbm, ecospat.cv.me, ecospat.cv.rf, ecospat.boyce, ecospat.CommunityEval, ecospat.cohen.kappa, ecospat.max.kappa, ecospat.max.tss, ecospat.meva.table, ecospat.plot.kappa, ecospat.plot.tss and ecospat.adj.D2.glm;
Spatial predictions and projections --> ecospat.ESM.Modeling, ecospat.ESM.EnsembleModeling, ecospat.ESM.Projection, ecospat.ESM.EnsembleProjection, ecospat.SESAM.prr, ecospat.migclim, ecospat.binary.model, ecospat.Epred and ecospat.mpa;
Variable Importance --> ecospat.maxentvarimport;
-Post Modelling:
Variance Partition --> ecospat.varpart;
Spatial predictions of species assemblages --> ecospat.cons_Cscore
The ecospat package was written by current and former members and collaborators of the ecospat group of Antoine Guisan, Department of Ecology and Evolution (DEE) & Institute of Earth Surface Dynamics (IDYST), University of Lausanne, Switzerland.
| Package: | ecospat |
| Type: | Package |
| Version: | 2.1.1 |
| Date: | 2016-11-02 |
| License: | GPL |