ecospat.niche.dyn.index (z1, z2, intersection=NA)intersection=NA, the analysis is performed on the whole environmental extent (native and invaded). If intersection=0, the analysis is performed at the intersection between native and invaded range. If intersection=0.05, the analysis is performed at the intersection of the 5th quantile of both native and invaded environmental densities.ecospat.grid.clim.dyn